def lorem_indo():
	return "Lorem Ipsum adalah contoh teks atau dummy"\
	+ "dalam industri percetakan dan typesetting."
	
def lorem_english():
	return "Lorem Ipsum is simply dummy text of the "\
	+ "printing and typesetting industry." 



from setuptools import setup


setup(name='package-pertama',
	  version='0.1',
	  description='Latihan membuat package di Python',
	  url='http://github.com/yanwarsolah/package-pertama',
	  author='Yanwar Solahudin',
	  author_email='yanwarsolah@gmail.com',
	  license='MIT',
	  packages=['package_pertama'],
	  zip_safe=False)
